/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.util.swing.beanbinding;

import org.jdesktop.beansbinding.Converter;

/**
 * <p>Converts String to double If String cannot be converted set's the value to
 * {@link Double#MIN_VALUE} This is used by the {@link DoubleValidator}</p>
 *
 * Works in conjunction with {@link DoubleConverter}<br/>
 * 
 * <p>
 * Usage:<br/>
 * 
 * yourBinding.setConverter(new {@link DoubleConverter}());<br/>
 * yourBinding.setValidator(new {@link DoubleValidator}());
 * </p>
 * 
 * @author Merijn Zengers
 */
public class DoubleConverter extends Converter<Double, String> {

    /**
     * Convert a Double to a String
     * @param arg
     * @return 
     */
    @Override
    public String convertForward(Double arg) {
        return String.valueOf(arg);
    }

    /**
     * <p>Convert a String to a {@link Double}</p>
     * 
     * If not able to convert the string to {@link Double} will return {@link Double#MIN_VALUE}
     * @param arg
     * @return converted String value or {@link Double#MIN_VALUE} if a {@link NumberFormatException} occurs
     */
    @Override
    public Double convertReverse(String arg) {
        double value;
        try {
            value = (arg == null) ? 0 : Double.parseDouble(arg);
        } catch (NumberFormatException ex) {
            value = Double.MIN_VALUE;
        }
        return value;
    }
}
