/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.util.swing.beanbinding;

import org.jdesktop.beansbinding.Validator;
import org.openide.util.NbBundle;

/**
 * <p>Validator for Double</p> 
 * 
 * <p>Checks if the value passed is {@link Double#MIN_VALUE}<br/> 
 * this indicates an error occurred trying to convert user input to value<br/>
 * Use the {@link DoubleConverter} to get this functionality</p>
 * 
 * <p>
 * Usage:<br/>
 * 
 * yourBinding.setConverter(new {@link DoubleConverter}());<br/>
 * yourBinding.setValidator(new {@link DoubleValidator}());
 * </p>
 * 
 *
 * @author Merijn Zengers
 */
@NbBundle.Messages("DoubleValidator invalid number message=Value should be a number")
public class DoubleValidator extends Validator<Double> {

        @Override
        public Validator.Result validate(Double arg) {
            if (arg == Double.MIN_VALUE) {
                return new Validator.Result(null, Bundle.DoubleValidator_invalid_number_message());
            }
            return null;
        }
    }