/*
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *          http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.util.swing.beanbinding;

import org.jdesktop.beansbinding.Converter;

/**
 *<p>
 * Converts String to Integer If String cannot be converted set's the value to {@link Integer#MIN_VALUE}
 * This is used by the {@link IntegerValidator}
 *</p>
 * 
 * <p>
 * Usage:<br/>
 * 
 * yourBinding.setConverter(new IntegerConverter());<br/>
 * yourBinding.setValidator(new IntegerValidator());
 * </p>
 * 
 * @author Merijn Zengers
 */
public class IntegerConverter extends Converter<Integer, String> {

    /**
     * Converts Integer to String
     * @param arg
     * @return 
     */
    @Override
    public String convertForward(Integer arg) {
        return String.valueOf(arg);
    }

    /**
     * <p>Tries to convert String to double</p>
     * 
     * If conversion fails will return {@link Integer#MIN_VALUE} 
     * @param arg
     * @return 
     */
    @Override
    public Integer convertReverse(String arg) {
        Integer value;
        try {
            value = (arg == null || arg.isEmpty()) ? null : Integer.parseInt(arg);
        } catch (NumberFormatException ex) {
            value = Integer.MIN_VALUE;
        }
        return value;
    }
}
