/*
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *          http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.util.swing.beanbinding;

import org.jdesktop.beansbinding.Validator;
import org.openide.util.NbBundle;

/**
 * <p>Validates if a provided value is an Integer or at least a non fractionated
 * number</p> <p> Works in conjunction with {@link IntegerConverter}<br/> </p>
 * <p> Usage:<br/>
 *
 * yourBinding.setConverter(new IntegerConverter());<br/>
 * yourBinding.setValidator(new IntegerValidator()); </p>
 *
 * @author Merijn Zengers
 */
@NbBundle.Messages("IntegerValidator non integer value message=Should be a non fractionated number")
public class IntegerValidator extends Validator<Integer> {

    /**
     * Checks if the value passed is {@link Integer#MIN_VALUE} this indicates an
     * error occurred trying to convert user input to value
     *
     * @param arg
     * @return {@link Result} if passed in value is not equal to {@link Integer#MIN_VALUE}
     */
    @Override
    public Validator.Result validate(Integer arg) {
        if (arg != null) {
            if (arg == Integer.MIN_VALUE) {
                return new Validator.Result(null, Bundle.IntegerValidator_non_integer_value_message());
            }
        }
        return null;
    }
}
