/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

package nl.cloudfarming.client.util.swing.icon;

import java.awt.Dimension;
import java.awt.Point;

/**
 * Enum defining and calculating badge position
 *
 * @author Frantisek Post
 */
public enum BadgePosition {

    NORTH_WEST(0),
    NORTH_EAST(1),
    SOUTH_WEST(2),
    SOUTH_EAST(3),
    NORTH(4),
    EAST(5),
    SOUTH(6),
    WEST(7);
    
    
    private static final int margin = 1;
    private int type;

    private BadgePosition(int type) {
        this.type = type;
    }

    public Point getBadgePosition(Dimension baseDimension, Dimension badgeDimension) {
        Point point = null;
        switch (type) {
            case 0:
                point = new Point(margin, margin);
                break;
            case 1:
                point = new Point(baseDimension.width - badgeDimension.width - margin, margin);
                break;
            case 2:
                point = new Point(margin, baseDimension.height - badgeDimension.height - margin);
                break;
            case 3:
                point = new Point(baseDimension.width - badgeDimension.width - margin, baseDimension.height - badgeDimension.height - margin);
                break;
            case 4:
                point = new Point((baseDimension.width - badgeDimension.width) / 2, margin);
                break;
            case 5:
                point = new Point(baseDimension.width - badgeDimension.width - margin, (baseDimension.height - badgeDimension.height) / 2);
                break;
            case 6:
                point = new Point((baseDimension.width - badgeDimension.width) / 2, baseDimension.height - badgeDimension.height - margin);
                break;
            case 7:
                point = new Point(margin, (baseDimension.height - badgeDimension.height) / 2);
                break;
            default:
                break;
        }

        return point;
    }
}
